# coding: utf-8

"""
    Getir-Locals Integration Swagger Documentation

    This documentation is created by Getir Developers for Getir-Locals Integration.For this integration, you need to take CLIENT NAME and CLIENT SECRET keys from Getir-dev team and use these keys for authentication. You also need to use access token provided after successful login to be able to use all other endpoints  You can view information about the active order through /orders/unapproved endpoints. The status of the order is managed via verify, prepare, handover and cancel endpoints. Details on order management are as follows:  For orders to be made by the Getir courier, the flow is as follows:  Supplier confirms order --verify<br />Supplier prepares order --prepare (1-2 minutes must pass before delivery)<br />Supplier hands over the order to Getir courier --handover<br />For Getir delivery, transactions are made by the Getir courier after handover.  A valid reason will be requested from the supplier to cancel an order. Valid reasons may vary depending on the instant status of the order. For this reason, before canceling an order, you have to get instant valid order cancellation reasons from /orders/{orderId}/cancel-options endpoint.   # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class SupplierApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_supplier(self, **kwargs):  # noqa: E501
        """get supplier data.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_supplier(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: SupplierDataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_supplier_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_supplier_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_supplier_with_http_info(self, **kwargs):  # noqa: E501
        """get supplier data.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_supplier_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: SupplierDataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_supplier" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/v1/suppliers/supplier', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SupplierDataResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def reset_password(self, **kwargs):  # noqa: E501
        """Shops can reset the password they use via this endpoint and create a new password.  # noqa: E501

        The password must comply with the following rules. <br> - The new password must be at least 8 characters. - The password must contain one digit. - The password must contain one lowercase letter. - The password must contain one uppercase letter. - The password must contain one special character. - The password must contain no whitespace.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reset_password(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PasswordResetRequest body:
        :return: ApiResponseVoid
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.reset_password_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.reset_password_with_http_info(**kwargs)  # noqa: E501
            return data

    def reset_password_with_http_info(self, **kwargs):  # noqa: E501
        """Shops can reset the password they use via this endpoint and create a new password.  # noqa: E501

        The password must comply with the following rules. <br> - The new password must be at least 8 characters. - The password must contain one digit. - The password must contain one lowercase letter. - The password must contain one uppercase letter. - The password must contain one special character. - The password must contain no whitespace.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reset_password_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PasswordResetRequest body:
        :return: ApiResponseVoid
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method reset_password" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/suppliers/password/reset', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApiResponseVoid',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Getir-Locals Integration Swagger Documentation

    This documentation is created by Getir Developers for Getir-Locals Integration.For this integration, you need to take CLIENT NAME and CLIENT SECRET keys from Getir-dev team and use these keys for authentication. You also need to use access token provided after successful login to be able to use all other endpoints  You can view information about the active order through /orders/unapproved endpoints. The status of the order is managed via verify, prepare, handover and cancel endpoints. Details on order management are as follows:  For orders to be made by the Getir courier, the flow is as follows:  Supplier confirms order --verify<br />Supplier prepares order --prepare (1-2 minutes must pass before delivery)<br />Supplier hands over the order to Getir courier --handover<br />For Getir delivery, transactions are made by the Getir courier after handover.  A valid reason will be requested from the supplier to cancel an order. Valid reasons may vary depending on the instant status of the order. For this reason, before canceling an order, you have to get instant valid order cancellation reasons from /orders/{orderId}/cancel-options endpoint.   # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.orders_api import OrdersApi  # noqa: E501
from swagger_client.rest import ApiException


class TestOrdersApi(unittest.TestCase):
    """OrdersApi unit test stubs"""

    def setUp(self):
        self.api = OrdersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cancel_options(self):
        """Test case for cancel_options

        This method is used to select cancel reasons according to delivery option.  # noqa: E501
        """
        pass

    def test_cancel_order(self):
        """Test case for cancel_order

        This method is used to cancel  the order.  # noqa: E501
        """
        pass

    def test_cancelled_orders(self):
        """Test case for cancelled_orders

        It is used to get the list of cancelled orders by shop.  # noqa: E501
        """
        pass

    def test_chain_unapproved_orders(self):
        """Test case for chain_unapproved_orders

        It is used to get the list of unapproved orders by chain.  # noqa: E501
        """
        pass

    def test_deliver_order(self):
        """Test case for deliver_order

        This method is used for the delivery of the prepared order.  # noqa: E501
        """
        pass

    def test_get_active_orders(self):
        """Test case for get_active_orders

        It is used to get the list of active orders by shop.  # noqa: E501
        """
        pass

    def test_get_order(self):
        """Test case for get_order

        This method is used to get details of an order  # noqa: E501
        """
        pass

    def test_get_order_report(self):
        """Test case for get_order_report

        It is used to get the list of orders by shopIds,startDate and endDate.  # noqa: E501
        """
        pass

    def test_get_shop_delivered_orders(self):
        """Test case for get_shop_delivered_orders

        It is used to get the list of delivered orders by shopId,startDate and endDate.  # noqa: E501
        """
        pass

    def test_handover_order(self):
        """Test case for handover_order

        This method is used for the delivery of the prepared order to the courier.  # noqa: E501
        """
        pass

    def test_prepare_order(self):
        """Test case for prepare_order

        This method is used to change the prepared order to the prepared status  # noqa: E501
        """
        pass

    def test_send_invoice(self):
        """Test case for send_invoice

        This method is used to send the order's invoice to the client  # noqa: E501
        """
        pass

    def test_unapproved_orders(self):
        """Test case for unapproved_orders

        It is used to get the list of unapproved orders by shop.  # noqa: E501
        """
        pass

    def test_verify_order(self):
        """Test case for verify_order

        This method is used to approve the incoming order by the shop  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Getir-Locals Integration Swagger Documentation

    This documentation is created by Getir Developers for Getir-Locals Integration.For this integration, you need to take CLIENT NAME and CLIENT SECRET keys from Getir-dev team and use these keys for authentication. You also need to use access token provided after successful login to be able to use all other endpoints  You can view information about the active order through /orders/unapproved endpoints. The status of the order is managed via verify, prepare, handover and cancel endpoints. Details on order management are as follows:  For orders to be made by the Getir courier, the flow is as follows:  Supplier confirms order --verify<br />Supplier prepares order --prepare (1-2 minutes must pass before delivery)<br />Supplier hands over the order to Getir courier --handover<br />For Getir delivery, transactions are made by the Getir courier after handover.  A valid reason will be requested from the supplier to cancel an order. Valid reasons may vary depending on the instant status of the order. For this reason, before canceling an order, you have to get instant valid order cancellation reasons from /orders/{orderId}/cancel-options endpoint.   # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.models.authentication_response import AuthenticationResponse  # noqa: E501
from swagger_client.rest import ApiException


class TestAuthenticationResponse(unittest.TestCase):
    """AuthenticationResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAuthenticationResponse(self):
        """Test AuthenticationResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.authentication_response.AuthenticationResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from swagger_client.api.auth_api import AuthApi
from swagger_client.api.health_api import HealthApi
from swagger_client.api.orders_api import OrdersApi
from swagger_client.api.products_api import ProductsApi
from swagger_client.api.shops_api import ShopsApi
from swagger_client.api.supplier_api import SupplierApi



# coding: utf-8

"""
    Getir-Locals Integration Swagger Documentation

    This documentation is created by Getir Developers for Getir-Locals Integration.For this integration, you need to take CLIENT NAME and CLIENT SECRET keys from Getir-dev team and use these keys for authentication. You also need to use access token provided after successful login to be able to use all other endpoints  You can view information about the active order through /orders/unapproved endpoints. The status of the order is managed via verify, prepare, handover and cancel endpoints. Details on order management are as follows:  For orders to be made by the Getir courier, the flow is as follows:  Supplier confirms order --verify<br />Supplier prepares order --prepare (1-2 minutes must pass before delivery)<br />Supplier hands over the order to Getir courier --handover<br />For Getir delivery, transactions are made by the Getir courier after handover.  A valid reason will be requested from the supplier to cancel an order. Valid reasons may vary depending on the instant status of the order. For this reason, before canceling an order, you have to get instant valid order cancellation reasons from /orders/{orderId}/cancel-options endpoint.   # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class FilterLineOrderResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'shop_id': 'str',
        'status': 'float',
        'checkout_date': 'str',
        'client_note': 'str',
        'confirmation_id': 'str',
        'total_price': 'float',
        'max_possible_amount_merchant_can_charge': 'float',
        'min_possible_amount_merchant_can_charge': 'float',
        'do_not_knock': 'bool',
        'drop_off_at_door': 'bool',
        'is_eco_friendly': 'bool',
        'delivery_type': 'int',
        'payment_method': 'int',
        'payment_method_text': 'PaymentMethodTextResponse',
        'customer': 'CustomerResponse',
        'invoice_address': 'InvoiceAddressResponse',
        'products': 'list[ProductResponse]'
    }

    attribute_map = {
        'id': 'id',
        'shop_id': 'shopId',
        'status': 'status',
        'checkout_date': 'checkoutDate',
        'client_note': 'clientNote',
        'confirmation_id': 'confirmationId',
        'total_price': 'totalPrice',
        'max_possible_amount_merchant_can_charge': 'maxPossibleAmountMerchantCanCharge',
        'min_possible_amount_merchant_can_charge': 'minPossibleAmountMerchantCanCharge',
        'do_not_knock': 'doNotKnock',
        'drop_off_at_door': 'dropOffAtDoor',
        'is_eco_friendly': 'isEcoFriendly',
        'delivery_type': 'deliveryType',
        'payment_method': 'paymentMethod',
        'payment_method_text': 'paymentMethodText',
        'customer': 'customer',
        'invoice_address': 'invoiceAddress',
        'products': 'products'
    }

    def __init__(self, id=None, shop_id=None, status=None, checkout_date=None, client_note=None, confirmation_id=None, total_price=None, max_possible_amount_merchant_can_charge=None, min_possible_amount_merchant_can_charge=None, do_not_knock=None, drop_off_at_door=None, is_eco_friendly=None, delivery_type=None, payment_method=None, payment_method_text=None, customer=None, invoice_address=None, products=None):  # noqa: E501
        """FilterLineOrderResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._shop_id = None
        self._status = None
        self._checkout_date = None
        self._client_note = None
        self._confirmation_id = None
        self._total_price = None
        self._max_possible_amount_merchant_can_charge = None
        self._min_possible_amount_merchant_can_charge = None
        self._do_not_knock = None
        self._drop_off_at_door = None
        self._is_eco_friendly = None
        self._delivery_type = None
        self._payment_method = None
        self._payment_method_text = None
        self._customer = None
        self._invoice_address = None
        self._products = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if shop_id is not None:
            self.shop_id = shop_id
        if status is not None:
            self.status = status
        if checkout_date is not None:
            self.checkout_date = checkout_date
        if client_note is not None:
            self.client_note = client_note
        if confirmation_id is not None:
            self.confirmation_id = confirmation_id
        if total_price is not None:
            self.total_price = total_price
        if max_possible_amount_merchant_can_charge is not None:
            self.max_possible_amount_merchant_can_charge = max_possible_amount_merchant_can_charge
        if min_possible_amount_merchant_can_charge is not None:
            self.min_possible_amount_merchant_can_charge = min_possible_amount_merchant_can_charge
        if do_not_knock is not None:
            self.do_not_knock = do_not_knock
        if drop_off_at_door is not None:
            self.drop_off_at_door = drop_off_at_door
        if is_eco_friendly is not None:
            self.is_eco_friendly = is_eco_friendly
        if delivery_type is not None:
            self.delivery_type = delivery_type
        if payment_method is not None:
            self.payment_method = payment_method
        if payment_method_text is not None:
            self.payment_method_text = payment_method_text
        if customer is not None:
            self.customer = customer
        if invoice_address is not None:
            self.invoice_address = invoice_address
        if products is not None:
            self.products = products

    @property
    def id(self):
        """Gets the id of this FilterLineOrderResponse.  # noqa: E501


        :return: The id of this FilterLineOrderResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this FilterLineOrderResponse.


        :param id: The id of this FilterLineOrderResponse.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def shop_id(self):
        """Gets the shop_id of this FilterLineOrderResponse.  # noqa: E501


        :return: The shop_id of this FilterLineOrderResponse.  # noqa: E501
        :rtype: str
        """
        return self._shop_id

    @shop_id.setter
    def shop_id(self, shop_id):
        """Sets the shop_id of this FilterLineOrderResponse.


        :param shop_id: The shop_id of this FilterLineOrderResponse.  # noqa: E501
        :type: str
        """

        self._shop_id = shop_id

    @property
    def status(self):
        """Gets the status of this FilterLineOrderResponse.  # noqa: E501


        :return: The status of this FilterLineOrderResponse.  # noqa: E501
        :rtype: float
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this FilterLineOrderResponse.


        :param status: The status of this FilterLineOrderResponse.  # noqa: E501
        :type: float
        """

        self._status = status

    @property
    def checkout_date(self):
        """Gets the checkout_date of this FilterLineOrderResponse.  # noqa: E501


        :return: The checkout_date of this FilterLineOrderResponse.  # noqa: E501
        :rtype: str
        """
        return self._checkout_date

    @checkout_date.setter
    def checkout_date(self, checkout_date):
        """Sets the checkout_date of this FilterLineOrderResponse.


        :param checkout_date: The checkout_date of this FilterLineOrderResponse.  # noqa: E501
        :type: str
        """

        self._checkout_date = checkout_date

    @property
    def client_note(self):
        """Gets the client_note of this FilterLineOrderResponse.  # noqa: E501


        :return: The client_note of this FilterLineOrderResponse.  # noqa: E501
        :rtype: str
        """
        return self._client_note

    @client_note.setter
    def client_note(self, client_note):
        """Sets the client_note of this FilterLineOrderResponse.


        :param client_note: The client_note of this FilterLineOrderResponse.  # noqa: E501
        :type: str
        """

        self._client_note = client_note

    @property
    def confirmation_id(self):
        """Gets the confirmation_id of this FilterLineOrderResponse.  # noqa: E501


        :return: The confirmation_id of this FilterLineOrderResponse.  # noqa: E501
        :rtype: str
        """
        return self._confirmation_id

    @confirmation_id.setter
    def confirmation_id(self, confirmation_id):
        """Sets the confirmation_id of this FilterLineOrderResponse.


        :param confirmation_id: The confirmation_id of this FilterLineOrderResponse.  # noqa: E501
        :type: str
        """

        self._confirmation_id = confirmation_id

    @property
    def total_price(self):
        """Gets the total_price of this FilterLineOrderResponse.  # noqa: E501


        :return: The total_price of this FilterLineOrderResponse.  # noqa: E501
        :rtype: float
        """
        return self._total_price

    @total_price.setter
    def total_price(self, total_price):
        """Sets the total_price of this FilterLineOrderResponse.


        :param total_price: The total_price of this FilterLineOrderResponse.  # noqa: E501
        :type: float
        """

        self._total_price = total_price

    @property
    def max_possible_amount_merchant_can_charge(self):
        """Gets the max_possible_amount_merchant_can_charge of this FilterLineOrderResponse.  # noqa: E501


        :return: The max_possible_amount_merchant_can_charge of this FilterLineOrderResponse.  # noqa: E501
        :rtype: float
        """
        return self._max_possible_amount_merchant_can_charge

    @max_possible_amount_merchant_can_charge.setter
    def max_possible_amount_merchant_can_charge(self, max_possible_amount_merchant_can_charge):
        """Sets the max_possible_amount_merchant_can_charge of this FilterLineOrderResponse.


        :param max_possible_amount_merchant_can_charge: The max_possible_amount_merchant_can_charge of this FilterLineOrderResponse.  # noqa: E501
        :type: float
        """

        self._max_possible_amount_merchant_can_charge = max_possible_amount_merchant_can_charge

    @property
    def min_possible_amount_merchant_can_charge(self):
        """Gets the min_possible_amount_merchant_can_charge of this FilterLineOrderResponse.  # noqa: E501


        :return: The min_possible_amount_merchant_can_charge of this FilterLineOrderResponse.  # noqa: E501
        :rtype: float
        """
        return self._min_possible_amount_merchant_can_charge

    @min_possible_amount_merchant_can_charge.setter
    def min_possible_amount_merchant_can_charge(self, min_possible_amount_merchant_can_charge):
        """Sets the min_possible_amount_merchant_can_charge of this FilterLineOrderResponse.


        :param min_possible_amount_merchant_can_charge: The min_possible_amount_merchant_can_charge of this FilterLineOrderResponse.  # noqa: E501
        :type: float
        """

        self._min_possible_amount_merchant_can_charge = min_possible_amount_merchant_can_charge

    @property
    def do_not_knock(self):
        """Gets the do_not_knock of this FilterLineOrderResponse.  # noqa: E501


        :return: The do_not_knock of this FilterLineOrderResponse.  # noqa: E501
        :rtype: bool
        """
        return self._do_not_knock

    @do_not_knock.setter
    def do_not_knock(self, do_not_knock):
        """Sets the do_not_knock of this FilterLineOrderResponse.


        :param do_not_knock: The do_not_knock of this FilterLineOrderResponse.  # noqa: E501
        :type: bool
        """

        self._do_not_knock = do_not_knock

    @property
    def drop_off_at_door(self):
        """Gets the drop_off_at_door of this FilterLineOrderResponse.  # noqa: E501


        :return: The drop_off_at_door of this FilterLineOrderResponse.  # noqa: E501
        :rtype: bool
        """
        return self._drop_off_at_door

    @drop_off_at_door.setter
    def drop_off_at_door(self, drop_off_at_door):
        """Sets the drop_off_at_door of this FilterLineOrderResponse.


        :param drop_off_at_door: The drop_off_at_door of this FilterLineOrderResponse.  # noqa: E501
        :type: bool
        """

        self._drop_off_at_door = drop_off_at_door

    @property
    def is_eco_friendly(self):
        """Gets the is_eco_friendly of this FilterLineOrderResponse.  # noqa: E501


        :return: The is_eco_friendly of this FilterLineOrderResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_eco_friendly

    @is_eco_friendly.setter
    def is_eco_friendly(self, is_eco_friendly):
        """Sets the is_eco_friendly of this FilterLineOrderResponse.


        :param is_eco_friendly: The is_eco_friendly of this FilterLineOrderResponse.  # noqa: E501
        :type: bool
        """

        self._is_eco_friendly = is_eco_friendly

    @property
    def delivery_type(self):
        """Gets the delivery_type of this FilterLineOrderResponse.  # noqa: E501


        :return: The delivery_type of this FilterLineOrderResponse.  # noqa: E501
        :rtype: int
        """
        return self._delivery_type

    @delivery_type.setter
    def delivery_type(self, delivery_type):
        """Sets the delivery_type of this FilterLineOrderResponse.


        :param delivery_type: The delivery_type of this FilterLineOrderResponse.  # noqa: E501
        :type: int
        """

        self._delivery_type = delivery_type

    @property
    def payment_method(self):
        """Gets the payment_method of this FilterLineOrderResponse.  # noqa: E501


        :return: The payment_method of this FilterLineOrderResponse.  # noqa: E501
        :rtype: int
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this FilterLineOrderResponse.


        :param payment_method: The payment_method of this FilterLineOrderResponse.  # noqa: E501
        :type: int
        """

        self._payment_method = payment_method

    @property
    def payment_method_text(self):
        """Gets the payment_method_text of this FilterLineOrderResponse.  # noqa: E501


        :return: The payment_method_text of this FilterLineOrderResponse.  # noqa: E501
        :rtype: PaymentMethodTextResponse
        """
        return self._payment_method_text

    @payment_method_text.setter
    def payment_method_text(self, payment_method_text):
        """Sets the payment_method_text of this FilterLineOrderResponse.


        :param payment_method_text: The payment_method_text of this FilterLineOrderResponse.  # noqa: E501
        :type: PaymentMethodTextResponse
        """

        self._payment_method_text = payment_method_text

    @property
    def customer(self):
        """Gets the customer of this FilterLineOrderResponse.  # noqa: E501


        :return: The customer of this FilterLineOrderResponse.  # noqa: E501
        :rtype: CustomerResponse
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """Sets the customer of this FilterLineOrderResponse.


        :param customer: The customer of this FilterLineOrderResponse.  # noqa: E501
        :type: CustomerResponse
        """

        self._customer = customer

    @property
    def invoice_address(self):
        """Gets the invoice_address of this FilterLineOrderResponse.  # noqa: E501


        :return: The invoice_address of this FilterLineOrderResponse.  # noqa: E501
        :rtype: InvoiceAddressResponse
        """
        return self._invoice_address

    @invoice_address.setter
    def invoice_address(self, invoice_address):
        """Sets the invoice_address of this FilterLineOrderResponse.


        :param invoice_address: The invoice_address of this FilterLineOrderResponse.  # noqa: E501
        :type: InvoiceAddressResponse
        """

        self._invoice_address = invoice_address

    @property
    def products(self):
        """Gets the products of this FilterLineOrderResponse.  # noqa: E501


        :return: The products of this FilterLineOrderResponse.  # noqa: E501
        :rtype: list[ProductResponse]
        """
        return self._products

    @products.setter
    def products(self, products):
        """Sets the products of this FilterLineOrderResponse.


        :param products: The products of this FilterLineOrderResponse.  # noqa: E501
        :type: list[ProductResponse]
        """

        self._products = products

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FilterLineOrderResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FilterLineOrderResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Getir-Locals Integration Swagger Documentation

    This documentation is created by Getir Developers for Getir-Locals Integration.For this integration, you need to take CLIENT NAME and CLIENT SECRET keys from Getir-dev team and use these keys for authentication. You also need to use access token provided after successful login to be able to use all other endpoints  You can view information about the active order through /orders/unapproved endpoints. The status of the order is managed via verify, prepare, handover and cancel endpoints. Details on order management are as follows:  For orders to be made by the Getir courier, the flow is as follows:  Supplier confirms order --verify<br />Supplier prepares order --prepare (1-2 minutes must pass before delivery)<br />Supplier hands over the order to Getir courier --handover<br />For Getir delivery, transactions are made by the Getir courier after handover.  A valid reason will be requested from the supplier to cancel an order. Valid reasons may vary depending on the instant status of the order. For this reason, before canceling an order, you have to get instant valid order cancellation reasons from /orders/{orderId}/cancel-options endpoint.   # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ProductResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'product': 'str',
        'catalog_product_id': 'str',
        'count': 'int',
        'name': 'NameResponse',
        'price': 'float',
        'total_price': 'float',
        'has_barcode': 'bool',
        'barcode': 'str',
        'note': 'str',
        'max_possible_price': 'float',
        'min_possible_price': 'float',
        'is_provision_available': 'bool',
        'max_total_weight': 'int',
        'min_total_weight': 'int',
        'total_weight': 'int'
    }

    attribute_map = {
        'id': 'id',
        'product': 'product',
        'catalog_product_id': 'catalogProductId',
        'count': 'count',
        'name': 'name',
        'price': 'price',
        'total_price': 'totalPrice',
        'has_barcode': 'hasBarcode',
        'barcode': 'barcode',
        'note': 'note',
        'max_possible_price': 'maxPossiblePrice',
        'min_possible_price': 'minPossiblePrice',
        'is_provision_available': 'isProvisionAvailable',
        'max_total_weight': 'maxTotalWeight',
        'min_total_weight': 'minTotalWeight',
        'total_weight': 'totalWeight'
    }

    def __init__(self, id=None, product=None, catalog_product_id=None, count=None, name=None, price=None, total_price=None, has_barcode=None, barcode=None, note=None, max_possible_price=None, min_possible_price=None, is_provision_available=None, max_total_weight=None, min_total_weight=None, total_weight=None):  # noqa: E501
        """ProductResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._product = None
        self._catalog_product_id = None
        self._count = None
        self._name = None
        self._price = None
        self._total_price = None
        self._has_barcode = None
        self._barcode = None
        self._note = None
        self._max_possible_price = None
        self._min_possible_price = None
        self._is_provision_available = None
        self._max_total_weight = None
        self._min_total_weight = None
        self._total_weight = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if product is not None:
            self.product = product
        if catalog_product_id is not None:
            self.catalog_product_id = catalog_product_id
        if count is not None:
            self.count = count
        if name is not None:
            self.name = name
        if price is not None:
            self.price = price
        if total_price is not None:
            self.total_price = total_price
        if has_barcode is not None:
            self.has_barcode = has_barcode
        if barcode is not None:
            self.barcode = barcode
        if note is not None:
            self.note = note
        if max_possible_price is not None:
            self.max_possible_price = max_possible_price
        if min_possible_price is not None:
            self.min_possible_price = min_possible_price
        if is_provision_available is not None:
            self.is_provision_available = is_provision_available
        if max_total_weight is not None:
            self.max_total_weight = max_total_weight
        if min_total_weight is not None:
            self.min_total_weight = min_total_weight
        if total_weight is not None:
            self.total_weight = total_weight

    @property
    def id(self):
        """Gets the id of this ProductResponse.  # noqa: E501


        :return: The id of this ProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ProductResponse.


        :param id: The id of this ProductResponse.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def product(self):
        """Gets the product of this ProductResponse.  # noqa: E501


        :return: The product of this ProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._product

    @product.setter
    def product(self, product):
        """Sets the product of this ProductResponse.


        :param product: The product of this ProductResponse.  # noqa: E501
        :type: str
        """

        self._product = product

    @property
    def catalog_product_id(self):
        """Gets the catalog_product_id of this ProductResponse.  # noqa: E501


        :return: The catalog_product_id of this ProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._catalog_product_id

    @catalog_product_id.setter
    def catalog_product_id(self, catalog_product_id):
        """Sets the catalog_product_id of this ProductResponse.


        :param catalog_product_id: The catalog_product_id of this ProductResponse.  # noqa: E501
        :type: str
        """

        self._catalog_product_id = catalog_product_id

    @property
    def count(self):
        """Gets the count of this ProductResponse.  # noqa: E501


        :return: The count of this ProductResponse.  # noqa: E501
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this ProductResponse.


        :param count: The count of this ProductResponse.  # noqa: E501
        :type: int
        """

        self._count = count

    @property
    def name(self):
        """Gets the name of this ProductResponse.  # noqa: E501


        :return: The name of this ProductResponse.  # noqa: E501
        :rtype: NameResponse
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ProductResponse.


        :param name: The name of this ProductResponse.  # noqa: E501
        :type: NameResponse
        """

        self._name = name

    @property
    def price(self):
        """Gets the price of this ProductResponse.  # noqa: E501


        :return: The price of this ProductResponse.  # noqa: E501
        :rtype: float
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this ProductResponse.


        :param price: The price of this ProductResponse.  # noqa: E501
        :type: float
        """

        self._price = price

    @property
    def total_price(self):
        """Gets the total_price of this ProductResponse.  # noqa: E501


        :return: The total_price of this ProductResponse.  # noqa: E501
        :rtype: float
        """
        return self._total_price

    @total_price.setter
    def total_price(self, total_price):
        """Sets the total_price of this ProductResponse.


        :param total_price: The total_price of this ProductResponse.  # noqa: E501
        :type: float
        """

        self._total_price = total_price

    @property
    def has_barcode(self):
        """Gets the has_barcode of this ProductResponse.  # noqa: E501


        :return: The has_barcode of this ProductResponse.  # noqa: E501
        :rtype: bool
        """
        return self._has_barcode

    @has_barcode.setter
    def has_barcode(self, has_barcode):
        """Sets the has_barcode of this ProductResponse.


        :param has_barcode: The has_barcode of this ProductResponse.  # noqa: E501
        :type: bool
        """

        self._has_barcode = has_barcode

    @property
    def barcode(self):
        """Gets the barcode of this ProductResponse.  # noqa: E501


        :return: The barcode of this ProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._barcode

    @barcode.setter
    def barcode(self, barcode):
        """Sets the barcode of this ProductResponse.


        :param barcode: The barcode of this ProductResponse.  # noqa: E501
        :type: str
        """

        self._barcode = barcode

    @property
    def note(self):
        """Gets the note of this ProductResponse.  # noqa: E501


        :return: The note of this ProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._note

    @note.setter
    def note(self, note):
        """Sets the note of this ProductResponse.


        :param note: The note of this ProductResponse.  # noqa: E501
        :type: str
        """

        self._note = note

    @property
    def max_possible_price(self):
        """Gets the max_possible_price of this ProductResponse.  # noqa: E501


        :return: The max_possible_price of this ProductResponse.  # noqa: E501
        :rtype: float
        """
        return self._max_possible_price

    @max_possible_price.setter
    def max_possible_price(self, max_possible_price):
        """Sets the max_possible_price of this ProductResponse.


        :param max_possible_price: The max_possible_price of this ProductResponse.  # noqa: E501
        :type: float
        """

        self._max_possible_price = max_possible_price

    @property
    def min_possible_price(self):
        """Gets the min_possible_price of this ProductResponse.  # noqa: E501


        :return: The min_possible_price of this ProductResponse.  # noqa: E501
        :rtype: float
        """
        return self._min_possible_price

    @min_possible_price.setter
    def min_possible_price(self, min_possible_price):
        """Sets the min_possible_price of this ProductResponse.


        :param min_possible_price: The min_possible_price of this ProductResponse.  # noqa: E501
        :type: float
        """

        self._min_possible_price = min_possible_price

    @property
    def is_provision_available(self):
        """Gets the is_provision_available of this ProductResponse.  # noqa: E501


        :return: The is_provision_available of this ProductResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_provision_available

    @is_provision_available.setter
    def is_provision_available(self, is_provision_available):
        """Sets the is_provision_available of this ProductResponse.


        :param is_provision_available: The is_provision_available of this ProductResponse.  # noqa: E501
        :type: bool
        """

        self._is_provision_available = is_provision_available

    @property
    def max_total_weight(self):
        """Gets the max_total_weight of this ProductResponse.  # noqa: E501


        :return: The max_total_weight of this ProductResponse.  # noqa: E501
        :rtype: int
        """
        return self._max_total_weight

    @max_total_weight.setter
    def max_total_weight(self, max_total_weight):
        """Sets the max_total_weight of this ProductResponse.


        :param max_total_weight: The max_total_weight of this ProductResponse.  # noqa: E501
        :type: int
        """

        self._max_total_weight = max_total_weight

    @property
    def min_total_weight(self):
        """Gets the min_total_weight of this ProductResponse.  # noqa: E501


        :return: The min_total_weight of this ProductResponse.  # noqa: E501
        :rtype: int
        """
        return self._min_total_weight

    @min_total_weight.setter
    def min_total_weight(self, min_total_weight):
        """Sets the min_total_weight of this ProductResponse.


        :param min_total_weight: The min_total_weight of this ProductResponse.  # noqa: E501
        :type: int
        """

        self._min_total_weight = min_total_weight

    @property
    def total_weight(self):
        """Gets the total_weight of this ProductResponse.  # noqa: E501


        :return: The total_weight of this ProductResponse.  # noqa: E501
        :rtype: int
        """
        return self._total_weight

    @total_weight.setter
    def total_weight(self, total_weight):
        """Sets the total_weight of this ProductResponse.


        :param total_weight: The total_weight of this ProductResponse.  # noqa: E501
        :type: int
        """

        self._total_weight = total_weight

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProductResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProductResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Getir-Locals Integration Swagger Documentation

    This documentation is created by Getir Developers for Getir-Locals Integration.For this integration, you need to take CLIENT NAME and CLIENT SECRET keys from Getir-dev team and use these keys for authentication. You also need to use access token provided after successful login to be able to use all other endpoints  You can view information about the active order through /orders/unapproved endpoints. The status of the order is managed via verify, prepare, handover and cancel endpoints. Details on order management are as follows:  For orders to be made by the Getir courier, the flow is as follows:  Supplier confirms order --verify<br />Supplier prepares order --prepare (1-2 minutes must pass before delivery)<br />Supplier hands over the order to Getir courier --handover<br />For Getir delivery, transactions are made by the Getir courier after handover.  A valid reason will be requested from the supplier to cancel an order. Valid reasons may vary depending on the instant status of the order. For this reason, before canceling an order, you have to get instant valid order cancellation reasons from /orders/{orderId}/cancel-options endpoint.   # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ShopProductsResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'status': 'float',
        'type': 'float',
        'price': 'float',
        'product_name': 'str',
        'catalog_product_id': 'str',
        'menu_product_id': 'str',
        'menu_options': 'list[MenuOptionsResponse]',
        'barcodes': 'list[str]'
    }

    attribute_map = {
        'status': 'status',
        'type': 'type',
        'price': 'price',
        'product_name': 'productName',
        'catalog_product_id': 'catalogProductId',
        'menu_product_id': 'menuProductId',
        'menu_options': 'menuOptions',
        'barcodes': 'barcodes'
    }

    def __init__(self, status=None, type=None, price=None, product_name=None, catalog_product_id=None, menu_product_id=None, menu_options=None, barcodes=None):  # noqa: E501
        """ShopProductsResponse - a model defined in Swagger"""  # noqa: E501
        self._status = None
        self._type = None
        self._price = None
        self._product_name = None
        self._catalog_product_id = None
        self._menu_product_id = None
        self._menu_options = None
        self._barcodes = None
        self.discriminator = None
        if status is not None:
            self.status = status
        if type is not None:
            self.type = type
        if price is not None:
            self.price = price
        if product_name is not None:
            self.product_name = product_name
        if catalog_product_id is not None:
            self.catalog_product_id = catalog_product_id
        if menu_product_id is not None:
            self.menu_product_id = menu_product_id
        if menu_options is not None:
            self.menu_options = menu_options
        if barcodes is not None:
            self.barcodes = barcodes

    @property
    def status(self):
        """Gets the status of this ShopProductsResponse.  # noqa: E501


        :return: The status of this ShopProductsResponse.  # noqa: E501
        :rtype: float
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ShopProductsResponse.


        :param status: The status of this ShopProductsResponse.  # noqa: E501
        :type: float
        """

        self._status = status

    @property
    def type(self):
        """Gets the type of this ShopProductsResponse.  # noqa: E501


        :return: The type of this ShopProductsResponse.  # noqa: E501
        :rtype: float
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ShopProductsResponse.


        :param type: The type of this ShopProductsResponse.  # noqa: E501
        :type: float
        """

        self._type = type

    @property
    def price(self):
        """Gets the price of this ShopProductsResponse.  # noqa: E501


        :return: The price of this ShopProductsResponse.  # noqa: E501
        :rtype: float
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this ShopProductsResponse.


        :param price: The price of this ShopProductsResponse.  # noqa: E501
        :type: float
        """

        self._price = price

    @property
    def product_name(self):
        """Gets the product_name of this ShopProductsResponse.  # noqa: E501


        :return: The product_name of this ShopProductsResponse.  # noqa: E501
        :rtype: str
        """
        return self._product_name

    @product_name.setter
    def product_name(self, product_name):
        """Sets the product_name of this ShopProductsResponse.


        :param product_name: The product_name of this ShopProductsResponse.  # noqa: E501
        :type: str
        """

        self._product_name = product_name

    @property
    def catalog_product_id(self):
        """Gets the catalog_product_id of this ShopProductsResponse.  # noqa: E501


        :return: The catalog_product_id of this ShopProductsResponse.  # noqa: E501
        :rtype: str
        """
        return self._catalog_product_id

    @catalog_product_id.setter
    def catalog_product_id(self, catalog_product_id):
        """Sets the catalog_product_id of this ShopProductsResponse.


        :param catalog_product_id: The catalog_product_id of this ShopProductsResponse.  # noqa: E501
        :type: str
        """

        self._catalog_product_id = catalog_product_id

    @property
    def menu_product_id(self):
        """Gets the menu_product_id of this ShopProductsResponse.  # noqa: E501


        :return: The menu_product_id of this ShopProductsResponse.  # noqa: E501
        :rtype: str
        """
        return self._menu_product_id

    @menu_product_id.setter
    def menu_product_id(self, menu_product_id):
        """Sets the menu_product_id of this ShopProductsResponse.


        :param menu_product_id: The menu_product_id of this ShopProductsResponse.  # noqa: E501
        :type: str
        """

        self._menu_product_id = menu_product_id

    @property
    def menu_options(self):
        """Gets the menu_options of this ShopProductsResponse.  # noqa: E501


        :return: The menu_options of this ShopProductsResponse.  # noqa: E501
        :rtype: list[MenuOptionsResponse]
        """
        return self._menu_options

    @menu_options.setter
    def menu_options(self, menu_options):
        """Sets the menu_options of this ShopProductsResponse.


        :param menu_options: The menu_options of this ShopProductsResponse.  # noqa: E501
        :type: list[MenuOptionsResponse]
        """

        self._menu_options = menu_options

    @property
    def barcodes(self):
        """Gets the barcodes of this ShopProductsResponse.  # noqa: E501


        :return: The barcodes of this ShopProductsResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._barcodes

    @barcodes.setter
    def barcodes(self, barcodes):
        """Sets the barcodes of this ShopProductsResponse.


        :param barcodes: The barcodes of this ShopProductsResponse.  # noqa: E501
        :type: list[str]
        """

        self._barcodes = barcodes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ShopProductsResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShopProductsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Getir-Locals Integration Swagger Documentation

    This documentation is created by Getir Developers for Getir-Locals Integration.For this integration, you need to take CLIENT NAME and CLIENT SECRET keys from Getir-dev team and use these keys for authentication. You also need to use access token provided after successful login to be able to use all other endpoints  You can view information about the active order through /orders/unapproved endpoints. The status of the order is managed via verify, prepare, handover and cancel endpoints. Details on order management are as follows:  For orders to be made by the Getir courier, the flow is as follows:  Supplier confirms order --verify<br />Supplier prepares order --prepare (1-2 minutes must pass before delivery)<br />Supplier hands over the order to Getir courier --handover<br />For Getir delivery, transactions are made by the Getir courier after handover.  A valid reason will be requested from the supplier to cancel an order. Valid reasons may vary depending on the instant status of the order. For this reason, before canceling an order, you have to get instant valid order cancellation reasons from /orders/{orderId}/cancel-options endpoint.   # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ApiResponseActiveOrder(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'order_id': 'str',
        'order_number': 'float',
        'shop_id': 'str',
        'chain_id': 'str',
        'status': 'float',
        'checkout_date': 'str',
        'client_note': 'str',
        'confirmation_id': 'str',
        'total_price': 'float',
        'shop_min_basket_amount': 'int',
        'getir_min_basket_amount': 'int',
        'client_batched_note': 'str',
        'max_possible_amount_merchant_can_charge': 'float',
        'min_possible_amount_merchant_can_charge': 'float',
        'do_not_knock': 'bool',
        'drop_off_at_door': 'bool',
        'is_eco_friendly': 'bool',
        'delivery_type': 'int',
        'payment_method': 'int',
        'payment_method_text': 'PaymentMethodTextResponse',
        'customer': 'CustomerResponse',
        'invoice_address': 'InvoiceAddressResponse',
        'products': 'list[ProductResponse]'
    }

    attribute_map = {
        'order_id': 'orderId',
        'order_number': 'orderNumber',
        'shop_id': 'shopId',
        'chain_id': 'chainId',
        'status': 'status',
        'checkout_date': 'checkoutDate',
        'client_note': 'clientNote',
        'confirmation_id': 'confirmationId',
        'total_price': 'totalPrice',
        'shop_min_basket_amount': 'shopMinBasketAmount',
        'getir_min_basket_amount': 'getirMinBasketAmount',
        'client_batched_note': 'clientBatchedNote',
        'max_possible_amount_merchant_can_charge': 'maxPossibleAmountMerchantCanCharge',
        'min_possible_amount_merchant_can_charge': 'minPossibleAmountMerchantCanCharge',
        'do_not_knock': 'doNotKnock',
        'drop_off_at_door': 'dropOffAtDoor',
        'is_eco_friendly': 'isEcoFriendly',
        'delivery_type': 'deliveryType',
        'payment_method': 'paymentMethod',
        'payment_method_text': 'paymentMethodText',
        'customer': 'customer',
        'invoice_address': 'invoiceAddress',
        'products': 'products'
    }

    def __init__(self, order_id=None, order_number=None, shop_id=None, chain_id=None, status=None, checkout_date=None, client_note=None, confirmation_id=None, total_price=None, shop_min_basket_amount=None, getir_min_basket_amount=None, client_batched_note=None, max_possible_amount_merchant_can_charge=None, min_possible_amount_merchant_can_charge=None, do_not_knock=None, drop_off_at_door=None, is_eco_friendly=None, delivery_type=None, payment_method=None, payment_method_text=None, customer=None, invoice_address=None, products=None):  # noqa: E501
        """ApiResponseActiveOrder - a model defined in Swagger"""  # noqa: E501
        self._order_id = None
        self._order_number = None
        self._shop_id = None
        self._chain_id = None
        self._status = None
        self._checkout_date = None
        self._client_note = None
        self._confirmation_id = None
        self._total_price = None
        self._shop_min_basket_amount = None
        self._getir_min_basket_amount = None
        self._client_batched_note = None
        self._max_possible_amount_merchant_can_charge = None
        self._min_possible_amount_merchant_can_charge = None
        self._do_not_knock = None
        self._drop_off_at_door = None
        self._is_eco_friendly = None
        self._delivery_type = None
        self._payment_method = None
        self._payment_method_text = None
        self._customer = None
        self._invoice_address = None
        self._products = None
        self.discriminator = None
        if order_id is not None:
            self.order_id = order_id
        if order_number is not None:
            self.order_number = order_number
        if shop_id is not None:
            self.shop_id = shop_id
        if chain_id is not None:
            self.chain_id = chain_id
        if status is not None:
            self.status = status
        if checkout_date is not None:
            self.checkout_date = checkout_date
        if client_note is not None:
            self.client_note = client_note
        if confirmation_id is not None:
            self.confirmation_id = confirmation_id
        if total_price is not None:
            self.total_price = total_price
        if shop_min_basket_amount is not None:
            self.shop_min_basket_amount = shop_min_basket_amount
        if getir_min_basket_amount is not None:
            self.getir_min_basket_amount = getir_min_basket_amount
        if client_batched_note is not None:
            self.client_batched_note = client_batched_note
        if max_possible_amount_merchant_can_charge is not None:
            self.max_possible_amount_merchant_can_charge = max_possible_amount_merchant_can_charge
        if min_possible_amount_merchant_can_charge is not None:
            self.min_possible_amount_merchant_can_charge = min_possible_amount_merchant_can_charge
        if do_not_knock is not None:
            self.do_not_knock = do_not_knock
        if drop_off_at_door is not None:
            self.drop_off_at_door = drop_off_at_door
        if is_eco_friendly is not None:
            self.is_eco_friendly = is_eco_friendly
        if delivery_type is not None:
            self.delivery_type = delivery_type
        if payment_method is not None:
            self.payment_method = payment_method
        if payment_method_text is not None:
            self.payment_method_text = payment_method_text
        if customer is not None:
            self.customer = customer
        if invoice_address is not None:
            self.invoice_address = invoice_address
        if products is not None:
            self.products = products

    @property
    def order_id(self):
        """Gets the order_id of this ApiResponseActiveOrder.  # noqa: E501


        :return: The order_id of this ApiResponseActiveOrder.  # noqa: E501
        :rtype: str
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        """Sets the order_id of this ApiResponseActiveOrder.


        :param order_id: The order_id of this ApiResponseActiveOrder.  # noqa: E501
        :type: str
        """

        self._order_id = order_id

    @property
    def order_number(self):
        """Gets the order_number of this ApiResponseActiveOrder.  # noqa: E501


        :return: The order_number of this ApiResponseActiveOrder.  # noqa: E501
        :rtype: float
        """
        return self._order_number

    @order_number.setter
    def order_number(self, order_number):
        """Sets the order_number of this ApiResponseActiveOrder.


        :param order_number: The order_number of this ApiResponseActiveOrder.  # noqa: E501
        :type: float
        """

        self._order_number = order_number

    @property
    def shop_id(self):
        """Gets the shop_id of this ApiResponseActiveOrder.  # noqa: E501


        :return: The shop_id of this ApiResponseActiveOrder.  # noqa: E501
        :rtype: str
        """
        return self._shop_id

    @shop_id.setter
    def shop_id(self, shop_id):
        """Sets the shop_id of this ApiResponseActiveOrder.


        :param shop_id: The shop_id of this ApiResponseActiveOrder.  # noqa: E501
        :type: str
        """

        self._shop_id = shop_id

    @property
    def chain_id(self):
        """Gets the chain_id of this ApiResponseActiveOrder.  # noqa: E501


        :return: The chain_id of this ApiResponseActiveOrder.  # noqa: E501
        :rtype: str
        """
        return self._chain_id

    @chain_id.setter
    def chain_id(self, chain_id):
        """Sets the chain_id of this ApiResponseActiveOrder.


        :param chain_id: The chain_id of this ApiResponseActiveOrder.  # noqa: E501
        :type: str
        """

        self._chain_id = chain_id

    @property
    def status(self):
        """Gets the status of this ApiResponseActiveOrder.  # noqa: E501


        :return: The status of this ApiResponseActiveOrder.  # noqa: E501
        :rtype: float
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ApiResponseActiveOrder.


        :param status: The status of this ApiResponseActiveOrder.  # noqa: E501
        :type: float
        """

        self._status = status

    @property
    def checkout_date(self):
        """Gets the checkout_date of this ApiResponseActiveOrder.  # noqa: E501


        :return: The checkout_date of this ApiResponseActiveOrder.  # noqa: E501
        :rtype: str
        """
        return self._checkout_date

    @checkout_date.setter
    def checkout_date(self, checkout_date):
        """Sets the checkout_date of this ApiResponseActiveOrder.


        :param checkout_date: The checkout_date of this ApiResponseActiveOrder.  # noqa: E501
        :type: str
        """

        self._checkout_date = checkout_date

    @property
    def client_note(self):
        """Gets the client_note of this ApiResponseActiveOrder.  # noqa: E501


        :return: The client_note of this ApiResponseActiveOrder.  # noqa: E501
        :rtype: str
        """
        return self._client_note

    @client_note.setter
    def client_note(self, client_note):
        """Sets the client_note of this ApiResponseActiveOrder.


        :param client_note: The client_note of this ApiResponseActiveOrder.  # noqa: E501
        :type: str
        """

        self._client_note = client_note

    @property
    def confirmation_id(self):
        """Gets the confirmation_id of this ApiResponseActiveOrder.  # noqa: E501


        :return: The confirmation_id of this ApiResponseActiveOrder.  # noqa: E501
        :rtype: str
        """
        return self._confirmation_id

    @confirmation_id.setter
    def confirmation_id(self, confirmation_id):
        """Sets the confirmation_id of this ApiResponseActiveOrder.


        :param confirmation_id: The confirmation_id of this ApiResponseActiveOrder.  # noqa: E501
        :type: str
        """

        self._confirmation_id = confirmation_id

    @property
    def total_price(self):
        """Gets the total_price of this ApiResponseActiveOrder.  # noqa: E501


        :return: The total_price of this ApiResponseActiveOrder.  # noqa: E501
        :rtype: float
        """
        return self._total_price

    @total_price.setter
    def total_price(self, total_price):
        """Sets the total_price of this ApiResponseActiveOrder.


        :param total_price: The total_price of this ApiResponseActiveOrder.  # noqa: E501
        :type: float
        """

        self._total_price = total_price

    @property
    def shop_min_basket_amount(self):
        """Gets the shop_min_basket_amount of this ApiResponseActiveOrder.  # noqa: E501


        :return: The shop_min_basket_amount of this ApiResponseActiveOrder.  # noqa: E501
        :rtype: int
        """
        return self._shop_min_basket_amount

    @shop_min_basket_amount.setter
    def shop_min_basket_amount(self, shop_min_basket_amount):
        """Sets the shop_min_basket_amount of this ApiResponseActiveOrder.


        :param shop_min_basket_amount: The shop_min_basket_amount of this ApiResponseActiveOrder.  # noqa: E501
        :type: int
        """

        self._shop_min_basket_amount = shop_min_basket_amount

    @property
    def getir_min_basket_amount(self):
        """Gets the getir_min_basket_amount of this ApiResponseActiveOrder.  # noqa: E501


        :return: The getir_min_basket_amount of this ApiResponseActiveOrder.  # noqa: E501
        :rtype: int
        """
        return self._getir_min_basket_amount

    @getir_min_basket_amount.setter
    def getir_min_basket_amount(self, getir_min_basket_amount):
        """Sets the getir_min_basket_amount of this ApiResponseActiveOrder.


        :param getir_min_basket_amount: The getir_min_basket_amount of this ApiResponseActiveOrder.  # noqa: E501
        :type: int
        """

        self._getir_min_basket_amount = getir_min_basket_amount

    @property
    def client_batched_note(self):
        """Gets the client_batched_note of this ApiResponseActiveOrder.  # noqa: E501


        :return: The client_batched_note of this ApiResponseActiveOrder.  # noqa: E501
        :rtype: str
        """
        return self._client_batched_note

    @client_batched_note.setter
    def client_batched_note(self, client_batched_note):
        """Sets the client_batched_note of this ApiResponseActiveOrder.


        :param client_batched_note: The client_batched_note of this ApiResponseActiveOrder.  # noqa: E501
        :type: str
        """

        self._client_batched_note = client_batched_note

    @property
    def max_possible_amount_merchant_can_charge(self):
        """Gets the max_possible_amount_merchant_can_charge of this ApiResponseActiveOrder.  # noqa: E501


        :return: The max_possible_amount_merchant_can_charge of this ApiResponseActiveOrder.  # noqa: E501
        :rtype: float
        """
        return self._max_possible_amount_merchant_can_charge

    @max_possible_amount_merchant_can_charge.setter
    def max_possible_amount_merchant_can_charge(self, max_possible_amount_merchant_can_charge):
        """Sets the max_possible_amount_merchant_can_charge of this ApiResponseActiveOrder.


        :param max_possible_amount_merchant_can_charge: The max_possible_amount_merchant_can_charge of this ApiResponseActiveOrder.  # noqa: E501
        :type: float
        """

        self._max_possible_amount_merchant_can_charge = max_possible_amount_merchant_can_charge

    @property
    def min_possible_amount_merchant_can_charge(self):
        """Gets the min_possible_amount_merchant_can_charge of this ApiResponseActiveOrder.  # noqa: E501


        :return: The min_possible_amount_merchant_can_charge of this ApiResponseActiveOrder.  # noqa: E501
        :rtype: float
        """
        return self._min_possible_amount_merchant_can_charge

    @min_possible_amount_merchant_can_charge.setter
    def min_possible_amount_merchant_can_charge(self, min_possible_amount_merchant_can_charge):
        """Sets the min_possible_amount_merchant_can_charge of this ApiResponseActiveOrder.


        :param min_possible_amount_merchant_can_charge: The min_possible_amount_merchant_can_charge of this ApiResponseActiveOrder.  # noqa: E501
        :type: float
        """

        self._min_possible_amount_merchant_can_charge = min_possible_amount_merchant_can_charge

    @property
    def do_not_knock(self):
        """Gets the do_not_knock of this ApiResponseActiveOrder.  # noqa: E501


        :return: The do_not_knock of this ApiResponseActiveOrder.  # noqa: E501
        :rtype: bool
        """
        return self._do_not_knock

    @do_not_knock.setter
    def do_not_knock(self, do_not_knock):
        """Sets the do_not_knock of this ApiResponseActiveOrder.


        :param do_not_knock: The do_not_knock of this ApiResponseActiveOrder.  # noqa: E501
        :type: bool
        """

        self._do_not_knock = do_not_knock

    @property
    def drop_off_at_door(self):
        """Gets the drop_off_at_door of this ApiResponseActiveOrder.  # noqa: E501


        :return: The drop_off_at_door of this ApiResponseActiveOrder.  # noqa: E501
        :rtype: bool
        """
        return self._drop_off_at_door

    @drop_off_at_door.setter
    def drop_off_at_door(self, drop_off_at_door):
        """Sets the drop_off_at_door of this ApiResponseActiveOrder.


        :param drop_off_at_door: The drop_off_at_door of this ApiResponseActiveOrder.  # noqa: E501
        :type: bool
        """

        self._drop_off_at_door = drop_off_at_door

    @property
    def is_eco_friendly(self):
        """Gets the is_eco_friendly of this ApiResponseActiveOrder.  # noqa: E501


        :return: The is_eco_friendly of this ApiResponseActiveOrder.  # noqa: E501
        :rtype: bool
        """
        return self._is_eco_friendly

    @is_eco_friendly.setter
    def is_eco_friendly(self, is_eco_friendly):
        """Sets the is_eco_friendly of this ApiResponseActiveOrder.


        :param is_eco_friendly: The is_eco_friendly of this ApiResponseActiveOrder.  # noqa: E501
        :type: bool
        """

        self._is_eco_friendly = is_eco_friendly

    @property
    def delivery_type(self):
        """Gets the delivery_type of this ApiResponseActiveOrder.  # noqa: E501


        :return: The delivery_type of this ApiResponseActiveOrder.  # noqa: E501
        :rtype: int
        """
        return self._delivery_type

    @delivery_type.setter
    def delivery_type(self, delivery_type):
        """Sets the delivery_type of this ApiResponseActiveOrder.


        :param delivery_type: The delivery_type of this ApiResponseActiveOrder.  # noqa: E501
        :type: int
        """

        self._delivery_type = delivery_type

    @property
    def payment_method(self):
        """Gets the payment_method of this ApiResponseActiveOrder.  # noqa: E501


        :return: The payment_method of this ApiResponseActiveOrder.  # noqa: E501
        :rtype: int
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this ApiResponseActiveOrder.


        :param payment_method: The payment_method of this ApiResponseActiveOrder.  # noqa: E501
        :type: int
        """

        self._payment_method = payment_method

    @property
    def payment_method_text(self):
        """Gets the payment_method_text of this ApiResponseActiveOrder.  # noqa: E501


        :return: The payment_method_text of this ApiResponseActiveOrder.  # noqa: E501
        :rtype: PaymentMethodTextResponse
        """
        return self._payment_method_text

    @payment_method_text.setter
    def payment_method_text(self, payment_method_text):
        """Sets the payment_method_text of this ApiResponseActiveOrder.


        :param payment_method_text: The payment_method_text of this ApiResponseActiveOrder.  # noqa: E501
        :type: PaymentMethodTextResponse
        """

        self._payment_method_text = payment_method_text

    @property
    def customer(self):
        """Gets the customer of this ApiResponseActiveOrder.  # noqa: E501


        :return: The customer of this ApiResponseActiveOrder.  # noqa: E501
        :rtype: CustomerResponse
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """Sets the customer of this ApiResponseActiveOrder.


        :param customer: The customer of this ApiResponseActiveOrder.  # noqa: E501
        :type: CustomerResponse
        """

        self._customer = customer

    @property
    def invoice_address(self):
        """Gets the invoice_address of this ApiResponseActiveOrder.  # noqa: E501


        :return: The invoice_address of this ApiResponseActiveOrder.  # noqa: E501
        :rtype: InvoiceAddressResponse
        """
        return self._invoice_address

    @invoice_address.setter
    def invoice_address(self, invoice_address):
        """Sets the invoice_address of this ApiResponseActiveOrder.


        :param invoice_address: The invoice_address of this ApiResponseActiveOrder.  # noqa: E501
        :type: InvoiceAddressResponse
        """

        self._invoice_address = invoice_address

    @property
    def products(self):
        """Gets the products of this ApiResponseActiveOrder.  # noqa: E501


        :return: The products of this ApiResponseActiveOrder.  # noqa: E501
        :rtype: list[ProductResponse]
        """
        return self._products

    @products.setter
    def products(self, products):
        """Sets the products of this ApiResponseActiveOrder.


        :param products: The products of this ApiResponseActiveOrder.  # noqa: E501
        :type: list[ProductResponse]
        """

        self._products = products

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ApiResponseActiveOrder, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApiResponseActiveOrder):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    Getir-Locals Integration Swagger Documentation

    This documentation is created by Getir Developers for Getir-Locals Integration.For this integration, you need to take CLIENT NAME and CLIENT SECRET keys from Getir-dev team and use these keys for authentication. You also need to use access token provided after successful login to be able to use all other endpoints  You can view information about the active order through /orders/unapproved endpoints. The status of the order is managed via verify, prepare, handover and cancel endpoints. Details on order management are as follows:  For orders to be made by the Getir courier, the flow is as follows:  Supplier confirms order --verify<br />Supplier prepares order --prepare (1-2 minutes must pass before delivery)<br />Supplier hands over the order to Getir courier --handover<br />For Getir delivery, transactions are made by the Getir courier after handover.  A valid reason will be requested from the supplier to cancel an order. Valid reasons may vary depending on the instant status of the order. For this reason, before canceling an order, you have to get instant valid order cancellation reasons from /orders/{orderId}/cancel-options endpoint.   # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from swagger_client.models.active_order_list_response import ActiveOrderListResponse
from swagger_client.models.api_response_active_order import ApiResponseActiveOrder
from swagger_client.models.api_response_authentication_response import ApiResponseAuthenticationResponse
from swagger_client.models.api_response_get_shop_response import ApiResponseGetShopResponse
from swagger_client.models.api_response_list_cancel_option_response import ApiResponseListCancelOptionResponse
from swagger_client.models.api_response_list_order_response import ApiResponseListOrderResponse
from swagger_client.models.api_response_object import ApiResponseObject
from swagger_client.models.api_response_order_report_response import ApiResponseOrderReportResponse
from swagger_client.models.api_response_order_report_response_wrapper import ApiResponseOrderReportResponseWrapper
from swagger_client.models.api_response_pageable_response_shop_products_response import ApiResponsePageableResponseShopProductsResponse
from swagger_client.models.api_response_pageable_response_shop_products_response_data import ApiResponsePageableResponseShopProductsResponseData
from swagger_client.models.api_response_price_and_quantity_batch_response import ApiResponsePriceAndQuantityBatchResponse
from swagger_client.models.api_response_price_and_quantity_batch_response_wrapper import ApiResponsePriceAndQuantityBatchResponseWrapper
from swagger_client.models.api_response_product_batch_ticket_response import ApiResponseProductBatchTicketResponse
from swagger_client.models.api_response_shop_couriers_working_status_response import ApiResponseShopCouriersWorkingStatusResponse
from swagger_client.models.api_response_shop_working_hours_response import ApiResponseShopWorkingHoursResponse
from swagger_client.models.api_response_void import ApiResponseVoid
from swagger_client.models.artisan_order_response import ArtisanOrderResponse
from swagger_client.models.artisan_order_response_wrapper import ArtisanOrderResponseWrapper
from swagger_client.models.authentication_response import AuthenticationResponse
from swagger_client.models.cancel_option_response import CancelOptionResponse
from swagger_client.models.cancel_order_request import CancelOrderRequest
from swagger_client.models.customer_response import CustomerResponse
from swagger_client.models.field_validation import FieldValidation
from swagger_client.models.filter_line_order_response import FilterLineOrderResponse
from swagger_client.models.filter_order_response import FilterOrderResponse
from swagger_client.models.general_error import GeneralError
from swagger_client.models.general_error_wrapper import GeneralErrorWrapper
from swagger_client.models.get_shop_response import GetShopResponse
from swagger_client.models.health_response import HealthResponse
from swagger_client.models.internal_error import InternalError
from swagger_client.models.internal_error_wrapper import InternalErrorWrapper
from swagger_client.models.invoice_address_response import InvoiceAddressResponse
from swagger_client.models.invoice_request import InvoiceRequest
from swagger_client.models.menu_options_response import MenuOptionsResponse
from swagger_client.models.model5001_internal_error import Model5001InternalError
from swagger_client.models.name_response import NameResponse
from swagger_client.models.operation_result import OperationResult
from swagger_client.models.order_dto_response import OrderDtoResponse
from swagger_client.models.order_response import OrderResponse
from swagger_client.models.page_size_invalid_error import PageSizeInvalidError
from swagger_client.models.page_size_invalid_error_meta import PageSizeInvalidErrorMeta
from swagger_client.models.pageable_response_supplier_product_response import PageableResponseSupplierProductResponse
from swagger_client.models.password_reset_request import PasswordResetRequest
from swagger_client.models.payment_method_text_response import PaymentMethodTextResponse
from swagger_client.models.prepared_order_request import PreparedOrderRequest
from swagger_client.models.price_and_quantity_batch_product_response import PriceAndQuantityBatchProductResponse
from swagger_client.models.product_batch_request import ProductBatchRequest
from swagger_client.models.product_batch_ticket_response import ProductBatchTicketResponse
from swagger_client.models.product_request import ProductRequest
from swagger_client.models.product_response import ProductResponse
from swagger_client.models.shop_couriers_working_status_response import ShopCouriersWorkingStatusResponse
from swagger_client.models.shop_products_response import ShopProductsResponse
from swagger_client.models.shop_working_hours_response import ShopWorkingHoursResponse
from swagger_client.models.supplier_data_chain_response import SupplierDataChainResponse
from swagger_client.models.supplier_data_response import SupplierDataResponse
from swagger_client.models.supplier_data_response_wrapper import SupplierDataResponseWrapper
from swagger_client.models.supplier_data_shop_response import SupplierDataShopResponse
from swagger_client.models.supplier_product_response import SupplierProductResponse
from swagger_client.models.update_shop_couriers_status_request import UpdateShopCouriersStatusRequest
from swagger_client.models.update_shop_status_request import UpdateShopStatusRequest
from swagger_client.models.update_shop_working_hours_request import UpdateShopWorkingHoursRequest
from swagger_client.models.updated_product import UpdatedProduct



# coding: utf-8

"""
    Getir-Locals Integration Swagger Documentation

    This documentation is created by Getir Developers for Getir-Locals Integration.For this integration, you need to take CLIENT NAME and CLIENT SECRET keys from Getir-dev team and use these keys for authentication. You also need to use access token provided after successful login to be able to use all other endpoints  You can view information about the active order through /orders/unapproved endpoints. The status of the order is managed via verify, prepare, handover and cancel endpoints. Details on order management are as follows:  For orders to be made by the Getir courier, the flow is as follows:  Supplier confirms order --verify<br />Supplier prepares order --prepare (1-2 minutes must pass before delivery)<br />Supplier hands over the order to Getir courier --handover<br />For Getir delivery, transactions are made by the Getir courier after handover.  A valid reason will be requested from the supplier to cancel an order. Valid reasons may vary depending on the instant status of the order. For this reason, before canceling an order, you have to get instant valid order cancellation reasons from /orders/{orderId}/cancel-options endpoint.   # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class OrdersApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def cancel_options(self, order_id, **kwargs):  # noqa: E501
        """This method is used to select cancel reasons according to delivery option.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_options(order_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str order_id: (required)
        :return: ApiResponseListCancelOptionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cancel_options_with_http_info(order_id, **kwargs)  # noqa: E501
        else:
            (data) = self.cancel_options_with_http_info(order_id, **kwargs)  # noqa: E501
            return data

    def cancel_options_with_http_info(self, order_id, **kwargs):  # noqa: E501
        """This method is used to select cancel reasons according to delivery option.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_options_with_http_info(order_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str order_id: (required)
        :return: ApiResponseListCancelOptionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['order_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cancel_options" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'order_id' is set
        if ('order_id' not in params or
                params['order_id'] is None):
            raise ValueError("Missing the required parameter `order_id` when calling `cancel_options`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'order_id' in params:
            path_params['orderId'] = params['order_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/v1/orders/{orderId}/cancel-options', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApiResponseListCancelOptionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cancel_order(self, body, order_id, shop_id, **kwargs):  # noqa: E501
        """This method is used to cancel  the order.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_order(body, order_id, shop_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CancelOrderRequest body: (required)
        :param str order_id: (required)
        :param str shop_id: (required)
        :return: ApiResponseObject
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cancel_order_with_http_info(body, order_id, shop_id, **kwargs)  # noqa: E501
        else:
            (data) = self.cancel_order_with_http_info(body, order_id, shop_id, **kwargs)  # noqa: E501
            return data

    def cancel_order_with_http_info(self, body, order_id, shop_id, **kwargs):  # noqa: E501
        """This method is used to cancel  the order.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_order_with_http_info(body, order_id, shop_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CancelOrderRequest body: (required)
        :param str order_id: (required)
        :param str shop_id: (required)
        :return: ApiResponseObject
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'order_id', 'shop_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cancel_order" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `cancel_order`")  # noqa: E501
        # verify the required parameter 'order_id' is set
        if ('order_id' not in params or
                params['order_id'] is None):
            raise ValueError("Missing the required parameter `order_id` when calling `cancel_order`")  # noqa: E501
        # verify the required parameter 'shop_id' is set
        if ('shop_id' not in params or
                params['shop_id'] is None):
            raise ValueError("Missing the required parameter `shop_id` when calling `cancel_order`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'order_id' in params:
            path_params['orderId'] = params['order_id']  # noqa: E501
        if 'shop_id' in params:
            path_params['shopId'] = params['shop_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/v1/orders/{orderId}/shop/{shopId}/cancel', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApiResponseObject',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def cancelled_orders(self, shop_id, **kwargs):  # noqa: E501
        """It is used to get the list of cancelled orders by shop.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancelled_orders(shop_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str shop_id: (required)
        :param date _date:
        :return: ApiResponseListOrderResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cancelled_orders_with_http_info(shop_id, **kwargs)  # noqa: E501
        else:
            (data) = self.cancelled_orders_with_http_info(shop_id, **kwargs)  # noqa: E501
            return data

    def cancelled_orders_with_http_info(self, shop_id, **kwargs):  # noqa: E501
        """It is used to get the list of cancelled orders by shop.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancelled_orders_with_http_info(shop_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str shop_id: (required)
        :param date _date:
        :return: ApiResponseListOrderResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['shop_id', '_date']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cancelled_orders" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'shop_id' is set
        if ('shop_id' not in params or
                params['shop_id'] is None):
            raise ValueError("Missing the required parameter `shop_id` when calling `cancelled_orders`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'shop_id' in params:
            query_params.append(('shopId', params['shop_id']))  # noqa: E501
        if '_date' in params:
            query_params.append(('date', params['_date']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/v1/orders/cancelled', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApiResponseListOrderResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def chain_unapproved_orders(self, chain_id, **kwargs):  # noqa: E501
        """It is used to get the list of unapproved orders by chain.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.chain_unapproved_orders(chain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str chain_id: (required)
        :return: ApiResponseListOrderResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.chain_unapproved_orders_with_http_info(chain_id, **kwargs)  # noqa: E501
        else:
            (data) = self.chain_unapproved_orders_with_http_info(chain_id, **kwargs)  # noqa: E501
            return data

    def chain_unapproved_orders_with_http_info(self, chain_id, **kwargs):  # noqa: E501
        """It is used to get the list of unapproved orders by chain.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.chain_unapproved_orders_with_http_info(chain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str chain_id: (required)
        :return: ApiResponseListOrderResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['chain_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method chain_unapproved_orders" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'chain_id' is set
        if ('chain_id' not in params or
                params['chain_id'] is None):
            raise ValueError("Missing the required parameter `chain_id` when calling `chain_unapproved_orders`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'chain_id' in params:
            query_params.append(('chainId', params['chain_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/v1/orders/unapproved/chain-based', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApiResponseListOrderResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def deliver_order(self, order_id, shop_id, **kwargs):  # noqa: E501
        """This method is used for the delivery of the prepared order.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.deliver_order(order_id, shop_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str order_id: (required)
        :param str shop_id: (required)
        :return: ApiResponseObject
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.deliver_order_with_http_info(order_id, shop_id, **kwargs)  # noqa: E501
        else:
            (data) = self.deliver_order_with_http_info(order_id, shop_id, **kwargs)  # noqa: E501
            return data

    def deliver_order_with_http_info(self, order_id, shop_id, **kwargs):  # noqa: E501
        """This method is used for the delivery of the prepared order.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.deliver_order_with_http_info(order_id, shop_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str order_id: (required)
        :param str shop_id: (required)
        :return: ApiResponseObject
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['order_id', 'shop_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method deliver_order" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'order_id' is set
        if ('order_id' not in params or
                params['order_id'] is None):
            raise ValueError("Missing the required parameter `order_id` when calling `deliver_order`")  # noqa: E501
        # verify the required parameter 'shop_id' is set
        if ('shop_id' not in params or
                params['shop_id'] is None):
            raise ValueError("Missing the required parameter `shop_id` when calling `deliver_order`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'order_id' in params:
            path_params['orderId'] = params['order_id']  # noqa: E501
        if 'shop_id' in params:
            path_params['shopId'] = params['shop_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/v1/orders/{orderId}/shop/{shopId}/deliver', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApiResponseObject',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_active_orders(self, shop_id, **kwargs):  # noqa: E501
        """It is used to get the list of active orders by shop.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_active_orders(shop_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str shop_id: (required)
        :return: ActiveOrderListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_active_orders_with_http_info(shop_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_active_orders_with_http_info(shop_id, **kwargs)  # noqa: E501
            return data

    def get_active_orders_with_http_info(self, shop_id, **kwargs):  # noqa: E501
        """It is used to get the list of active orders by shop.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_active_orders_with_http_info(shop_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str shop_id: (required)
        :return: ActiveOrderListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['shop_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_active_orders" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'shop_id' is set
        if ('shop_id' not in params or
                params['shop_id'] is None):
            raise ValueError("Missing the required parameter `shop_id` when calling `get_active_orders`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'shop_id' in params:
            path_params['shopId'] = params['shop_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/v1/orders/{shopId}/active-orders', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ActiveOrderListResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_order(self, order_id, **kwargs):  # noqa: E501
        """This method is used to get details of an order  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_order(order_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str order_id: (required)
        :return: ArtisanOrderResponseWrapper
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_order_with_http_info(order_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_order_with_http_info(order_id, **kwargs)  # noqa: E501
            return data

    def get_order_with_http_info(self, order_id, **kwargs):  # noqa: E501
        """This method is used to get details of an order  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_order_with_http_info(order_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str order_id: (required)
        :return: ArtisanOrderResponseWrapper
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['order_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_order" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'order_id' is set
        if ('order_id' not in params or
                params['order_id'] is None):
            raise ValueError("Missing the required parameter `order_id` when calling `get_order`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'order_id' in params:
            path_params['orderId'] = params['order_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/v1/orders/{orderId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ArtisanOrderResponseWrapper',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_order_report(self, start_date, end_date, shop_id, page, page_size, **kwargs):  # noqa: E501
        """It is used to get the list of orders by shopIds,startDate and endDate.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_order_report(start_date, end_date, shop_id, page, page_size, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str start_date: Date format pattern is \"yyyy-MM-dd\". (required)
        :param str end_date: Date format pattern is \"yyyy-MM-dd\". (required)
        :param str shop_id: (required)
        :param float page: (required)
        :param float page_size: (required)
        :return: ApiResponseOrderReportResponseWrapper
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_order_report_with_http_info(start_date, end_date, shop_id, page, page_size, **kwargs)  # noqa: E501
        else:
            (data) = self.get_order_report_with_http_info(start_date, end_date, shop_id, page, page_size, **kwargs)  # noqa: E501
            return data

    def get_order_report_with_http_info(self, start_date, end_date, shop_id, page, page_size, **kwargs):  # noqa: E501
        """It is used to get the list of orders by shopIds,startDate and endDate.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_order_report_with_http_info(start_date, end_date, shop_id, page, page_size, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str start_date: Date format pattern is \"yyyy-MM-dd\". (required)
        :param str end_date: Date format pattern is \"yyyy-MM-dd\". (required)
        :param str shop_id: (required)
        :param float page: (required)
        :param float page_size: (required)
        :return: ApiResponseOrderReportResponseWrapper
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start_date', 'end_date', 'shop_id', 'page', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_order_report" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'start_date' is set
        if ('start_date' not in params or
                params['start_date'] is None):
            raise ValueError("Missing the required parameter `start_date` when calling `get_order_report`")  # noqa: E501
        # verify the required parameter 'end_date' is set
        if ('end_date' not in params or
                params['end_date'] is None):
            raise ValueError("Missing the required parameter `end_date` when calling `get_order_report`")  # noqa: E501
        # verify the required parameter 'shop_id' is set
        if ('shop_id' not in params or
                params['shop_id'] is None):
            raise ValueError("Missing the required parameter `shop_id` when calling `get_order_report`")  # noqa: E501
        # verify the required parameter 'page' is set
        if ('page' not in params or
                params['page'] is None):
            raise ValueError("Missing the required parameter `page` when calling `get_order_report`")  # noqa: E501
        # verify the required parameter 'page_size' is set
        if ('page_size' not in params or
                params['page_size'] is None):
            raise ValueError("Missing the required parameter `page_size` when calling `get_order_report`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_date' in params:
            query_params.append(('startDate', params['start_date']))  # noqa: E501
        if 'end_date' in params:
            query_params.append(('endDate', params['end_date']))  # noqa: E501
        if 'shop_id' in params:
            query_params.append(('shopId', params['shop_id']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/v1/orders/report', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApiResponseOrderReportResponseWrapper',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_shop_delivered_orders(self, start_date, end_date, shop_id, page, page_size, **kwargs):  # noqa: E501
        """It is used to get the list of delivered orders by shopId,startDate and endDate.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_shop_delivered_orders(start_date, end_date, shop_id, page, page_size, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date start_date: Date format pattern is \"yyyy-MM-dd'T'HH:mm:ss.SSSXXX\". (required)
        :param date end_date: Date format pattern is \"yyyy-MM-dd'T'HH:mm:ss.SSSXXX \". (required)
        :param str shop_id: (required)
        :param float page: (required)
        :param float page_size: (required)
        :return: FilterOrderResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_shop_delivered_orders_with_http_info(start_date, end_date, shop_id, page, page_size, **kwargs)  # noqa: E501
        else:
            (data) = self.get_shop_delivered_orders_with_http_info(start_date, end_date, shop_id, page, page_size, **kwargs)  # noqa: E501
            return data

    def get_shop_delivered_orders_with_http_info(self, start_date, end_date, shop_id, page, page_size, **kwargs):  # noqa: E501
        """It is used to get the list of delivered orders by shopId,startDate and endDate.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_shop_delivered_orders_with_http_info(start_date, end_date, shop_id, page, page_size, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date start_date: Date format pattern is \"yyyy-MM-dd'T'HH:mm:ss.SSSXXX\". (required)
        :param date end_date: Date format pattern is \"yyyy-MM-dd'T'HH:mm:ss.SSSXXX \". (required)
        :param str shop_id: (required)
        :param float page: (required)
        :param float page_size: (required)
        :return: FilterOrderResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start_date', 'end_date', 'shop_id', 'page', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_shop_delivered_orders" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'start_date' is set
        if ('start_date' not in params or
                params['start_date'] is None):
            raise ValueError("Missing the required parameter `start_date` when calling `get_shop_delivered_orders`")  # noqa: E501
        # verify the required parameter 'end_date' is set
        if ('end_date' not in params or
                params['end_date'] is None):
            raise ValueError("Missing the required parameter `end_date` when calling `get_shop_delivered_orders`")  # noqa: E501
        # verify the required parameter 'shop_id' is set
        if ('shop_id' not in params or
                params['shop_id'] is None):
            raise ValueError("Missing the required parameter `shop_id` when calling `get_shop_delivered_orders`")  # noqa: E501
        # verify the required parameter 'page' is set
        if ('page' not in params or
                params['page'] is None):
            raise ValueError("Missing the required parameter `page` when calling `get_shop_delivered_orders`")  # noqa: E501
        # verify the required parameter 'page_size' is set
        if ('page_size' not in params or
                params['page_size'] is None):
            raise ValueError("Missing the required parameter `page_size` when calling `get_shop_delivered_orders`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_date' in params:
            query_params.append(('startDate', params['start_date']))  # noqa: E501
        if 'end_date' in params:
            query_params.append(('endDate', params['end_date']))  # noqa: E501
        if 'shop_id' in params:
            query_params.append(('shopId', params['shop_id']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orders/delivered', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FilterOrderResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def handover_order(self, order_id, shop_id, **kwargs):  # noqa: E501
        """This method is used for the delivery of the prepared order to the courier.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.handover_order(order_id, shop_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str order_id: (required)
        :param str shop_id: (required)
        :return: ApiResponseObject
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.handover_order_with_http_info(order_id, shop_id, **kwargs)  # noqa: E501
        else:
            (data) = self.handover_order_with_http_info(order_id, shop_id, **kwargs)  # noqa: E501
            return data

    def handover_order_with_http_info(self, order_id, shop_id, **kwargs):  # noqa: E501
        """This method is used for the delivery of the prepared order to the courier.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.handover_order_with_http_info(order_id, shop_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str order_id: (required)
        :param str shop_id: (required)
        :return: ApiResponseObject
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['order_id', 'shop_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method handover_order" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'order_id' is set
        if ('order_id' not in params or
                params['order_id'] is None):
            raise ValueError("Missing the required parameter `order_id` when calling `handover_order`")  # noqa: E501
        # verify the required parameter 'shop_id' is set
        if ('shop_id' not in params or
                params['shop_id'] is None):
            raise ValueError("Missing the required parameter `shop_id` when calling `handover_order`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'order_id' in params:
            path_params['orderId'] = params['order_id']  # noqa: E501
        if 'shop_id' in params:
            path_params['shopId'] = params['shop_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/v1/orders/{orderId}/shop/{shopId}/handover', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApiResponseObject',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def prepare_order(self, order_id, shop_id, **kwargs):  # noqa: E501
        """This method is used to change the prepared order to the prepared status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.prepare_order(order_id, shop_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str order_id: (required)
        :param str shop_id: (required)
        :param PreparedOrderRequest body:
        :return: ApiResponseObject
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.prepare_order_with_http_info(order_id, shop_id, **kwargs)  # noqa: E501
        else:
            (data) = self.prepare_order_with_http_info(order_id, shop_id, **kwargs)  # noqa: E501
            return data

    def prepare_order_with_http_info(self, order_id, shop_id, **kwargs):  # noqa: E501
        """This method is used to change the prepared order to the prepared status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.prepare_order_with_http_info(order_id, shop_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str order_id: (required)
        :param str shop_id: (required)
        :param PreparedOrderRequest body:
        :return: ApiResponseObject
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['order_id', 'shop_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method prepare_order" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'order_id' is set
        if ('order_id' not in params or
                params['order_id'] is None):
            raise ValueError("Missing the required parameter `order_id` when calling `prepare_order`")  # noqa: E501
        # verify the required parameter 'shop_id' is set
        if ('shop_id' not in params or
                params['shop_id'] is None):
            raise ValueError("Missing the required parameter `shop_id` when calling `prepare_order`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'order_id' in params:
            path_params['orderId'] = params['order_id']  # noqa: E501
        if 'shop_id' in params:
            path_params['shopId'] = params['shop_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/v1/orders/{orderId}/shop/{shopId}/prepare', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApiResponseObject',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def send_invoice(self, order_id, **kwargs):  # noqa: E501
        """This method is used to send the order's invoice to the client  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_invoice(order_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str order_id: (required)
        :param InvoiceRequest body:
        :return: ApiResponseVoid
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.send_invoice_with_http_info(order_id, **kwargs)  # noqa: E501
        else:
            (data) = self.send_invoice_with_http_info(order_id, **kwargs)  # noqa: E501
            return data

    def send_invoice_with_http_info(self, order_id, **kwargs):  # noqa: E501
        """This method is used to send the order's invoice to the client  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_invoice_with_http_info(order_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str order_id: (required)
        :param InvoiceRequest body:
        :return: ApiResponseVoid
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['order_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method send_invoice" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'order_id' is set
        if ('order_id' not in params or
                params['order_id'] is None):
            raise ValueError("Missing the required parameter `order_id` when calling `send_invoice`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'order_id' in params:
            path_params['orderId'] = params['order_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/v1/orders/{orderId}/invoice-link', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApiResponseVoid',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def unapproved_orders(self, shop_id, **kwargs):  # noqa: E501
        """It is used to get the list of unapproved orders by shop.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.unapproved_orders(shop_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str shop_id: (required)
        :return: ApiResponseListOrderResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.unapproved_orders_with_http_info(shop_id, **kwargs)  # noqa: E501
        else:
            (data) = self.unapproved_orders_with_http_info(shop_id, **kwargs)  # noqa: E501
            return data

    def unapproved_orders_with_http_info(self, shop_id, **kwargs):  # noqa: E501
        """It is used to get the list of unapproved orders by shop.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.unapproved_orders_with_http_info(shop_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str shop_id: (required)
        :return: ApiResponseListOrderResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['shop_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method unapproved_orders" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'shop_id' is set
        if ('shop_id' not in params or
                params['shop_id'] is None):
            raise ValueError("Missing the required parameter `shop_id` when calling `unapproved_orders`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'shop_id' in params:
            query_params.append(('shopId', params['shop_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/v1/orders/unapproved', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApiResponseListOrderResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def verify_order(self, order_id, shop_id, **kwargs):  # noqa: E501
        """This method is used to approve the incoming order by the shop  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.verify_order(order_id, shop_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str order_id: (required)
        :param str shop_id: (required)
        :return: ApiResponseObject
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.verify_order_with_http_info(order_id, shop_id, **kwargs)  # noqa: E501
        else:
            (data) = self.verify_order_with_http_info(order_id, shop_id, **kwargs)  # noqa: E501
            return data

    def verify_order_with_http_info(self, order_id, shop_id, **kwargs):  # noqa: E501
        """This method is used to approve the incoming order by the shop  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.verify_order_with_http_info(order_id, shop_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str order_id: (required)
        :param str shop_id: (required)
        :return: ApiResponseObject
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['order_id', 'shop_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method verify_order" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'order_id' is set
        if ('order_id' not in params or
                params['order_id'] is None):
            raise ValueError("Missing the required parameter `order_id` when calling `verify_order`")  # noqa: E501
        # verify the required parameter 'shop_id' is set
        if ('shop_id' not in params or
                params['shop_id'] is None):
            raise ValueError("Missing the required parameter `shop_id` when calling `verify_order`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'order_id' in params:
            path_params['orderId'] = params['order_id']  # noqa: E501
        if 'shop_id' in params:
            path_params['shopId'] = params['shop_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/v1/orders/{orderId}/shop/{shopId}/verify', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApiResponseObject',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Getir-Locals Integration Swagger Documentation

    This documentation is created by Getir Developers for Getir-Locals Integration.For this integration, you need to take CLIENT NAME and CLIENT SECRET keys from Getir-dev team and use these keys for authentication. You also need to use access token provided after successful login to be able to use all other endpoints  You can view information about the active order through /orders/unapproved endpoints. The status of the order is managed via verify, prepare, handover and cancel endpoints. Details on order management are as follows:  For orders to be made by the Getir courier, the flow is as follows:  Supplier confirms order --verify<br />Supplier prepares order --prepare (1-2 minutes must pass before delivery)<br />Supplier hands over the order to Getir courier --handover<br />For Getir delivery, transactions are made by the Getir courier after handover.  A valid reason will be requested from the supplier to cancel an order. Valid reasons may vary depending on the instant status of the order. For this reason, before canceling an order, you have to get instant valid order cancellation reasons from /orders/{orderId}/cancel-options endpoint.   # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SupplierProductResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'product_id': 'str',
        'brand': 'str',
        'type': 'str',
        'name': 'str',
        'images': 'list[str]',
        'description': 'str',
        'catalog_sub_category_name': 'str',
        'catalog_category_name': 'str',
        'vendor_id': 'str',
        'barcodes': 'list[str]'
    }

    attribute_map = {
        'product_id': 'productId',
        'brand': 'brand',
        'type': 'type',
        'name': 'name',
        'images': 'images',
        'description': 'description',
        'catalog_sub_category_name': 'catalogSubCategoryName',
        'catalog_category_name': 'catalogCategoryName',
        'vendor_id': 'vendorId',
        'barcodes': 'barcodes'
    }

    def __init__(self, product_id=None, brand=None, type=None, name=None, images=None, description=None, catalog_sub_category_name=None, catalog_category_name=None, vendor_id=None, barcodes=None):  # noqa: E501
        """SupplierProductResponse - a model defined in Swagger"""  # noqa: E501
        self._product_id = None
        self._brand = None
        self._type = None
        self._name = None
        self._images = None
        self._description = None
        self._catalog_sub_category_name = None
        self._catalog_category_name = None
        self._vendor_id = None
        self._barcodes = None
        self.discriminator = None
        if product_id is not None:
            self.product_id = product_id
        if brand is not None:
            self.brand = brand
        if type is not None:
            self.type = type
        if name is not None:
            self.name = name
        if images is not None:
            self.images = images
        if description is not None:
            self.description = description
        if catalog_sub_category_name is not None:
            self.catalog_sub_category_name = catalog_sub_category_name
        if catalog_category_name is not None:
            self.catalog_category_name = catalog_category_name
        if vendor_id is not None:
            self.vendor_id = vendor_id
        if barcodes is not None:
            self.barcodes = barcodes

    @property
    def product_id(self):
        """Gets the product_id of this SupplierProductResponse.  # noqa: E501


        :return: The product_id of this SupplierProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._product_id

    @product_id.setter
    def product_id(self, product_id):
        """Sets the product_id of this SupplierProductResponse.


        :param product_id: The product_id of this SupplierProductResponse.  # noqa: E501
        :type: str
        """

        self._product_id = product_id

    @property
    def brand(self):
        """Gets the brand of this SupplierProductResponse.  # noqa: E501


        :return: The brand of this SupplierProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._brand

    @brand.setter
    def brand(self, brand):
        """Sets the brand of this SupplierProductResponse.


        :param brand: The brand of this SupplierProductResponse.  # noqa: E501
        :type: str
        """

        self._brand = brand

    @property
    def type(self):
        """Gets the type of this SupplierProductResponse.  # noqa: E501


        :return: The type of this SupplierProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this SupplierProductResponse.


        :param type: The type of this SupplierProductResponse.  # noqa: E501
        :type: str
        """
        allowed_values = ["COUNT", "GR", "LT"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def name(self):
        """Gets the name of this SupplierProductResponse.  # noqa: E501


        :return: The name of this SupplierProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SupplierProductResponse.


        :param name: The name of this SupplierProductResponse.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def images(self):
        """Gets the images of this SupplierProductResponse.  # noqa: E501


        :return: The images of this SupplierProductResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._images

    @images.setter
    def images(self, images):
        """Sets the images of this SupplierProductResponse.


        :param images: The images of this SupplierProductResponse.  # noqa: E501
        :type: list[str]
        """

        self._images = images

    @property
    def description(self):
        """Gets the description of this SupplierProductResponse.  # noqa: E501


        :return: The description of this SupplierProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this SupplierProductResponse.


        :param description: The description of this SupplierProductResponse.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def catalog_sub_category_name(self):
        """Gets the catalog_sub_category_name of this SupplierProductResponse.  # noqa: E501


        :return: The catalog_sub_category_name of this SupplierProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._catalog_sub_category_name

    @catalog_sub_category_name.setter
    def catalog_sub_category_name(self, catalog_sub_category_name):
        """Sets the catalog_sub_category_name of this SupplierProductResponse.


        :param catalog_sub_category_name: The catalog_sub_category_name of this SupplierProductResponse.  # noqa: E501
        :type: str
        """

        self._catalog_sub_category_name = catalog_sub_category_name

    @property
    def catalog_category_name(self):
        """Gets the catalog_category_name of this SupplierProductResponse.  # noqa: E501


        :return: The catalog_category_name of this SupplierProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._catalog_category_name

    @catalog_category_name.setter
    def catalog_category_name(self, catalog_category_name):
        """Sets the catalog_category_name of this SupplierProductResponse.


        :param catalog_category_name: The catalog_category_name of this SupplierProductResponse.  # noqa: E501
        :type: str
        """

        self._catalog_category_name = catalog_category_name

    @property
    def vendor_id(self):
        """Gets the vendor_id of this SupplierProductResponse.  # noqa: E501


        :return: The vendor_id of this SupplierProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._vendor_id

    @vendor_id.setter
    def vendor_id(self, vendor_id):
        """Sets the vendor_id of this SupplierProductResponse.


        :param vendor_id: The vendor_id of this SupplierProductResponse.  # noqa: E501
        :type: str
        """

        self._vendor_id = vendor_id

    @property
    def barcodes(self):
        """Gets the barcodes of this SupplierProductResponse.  # noqa: E501


        :return: The barcodes of this SupplierProductResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._barcodes

    @barcodes.setter
    def barcodes(self, barcodes):
        """Sets the barcodes of this SupplierProductResponse.


        :param barcodes: The barcodes of this SupplierProductResponse.  # noqa: E501
        :type: list[str]
        """

        self._barcodes = barcodes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SupplierProductResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SupplierProductResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
